.. _io.vasp:

VASP
====

.. module:: sisl.io.vasp

.. autosummary::
   :toctree: generated/

   carSileVASP
   doscarSileVASP
   eigenvalSileVASP
   chgSileVASP
   locpotSileVASP
   outcarSileVASP


.. autosummary::
   :toctree: generated/
   :hidden:

   SileVASP
   SileBinVASP
